@@ -5,7 +5,7 @@
 from pyparsing import Word, srange
 
 koreanChars = srange(r"[\0xac00-\0xd7a3]")
-koreanWord = Word(koreanChars)
+koreanWord = Word(koreanChars,min=2)
 
 # define grammar
 greet = koreanWord + "," + koreanWord + "!"
